@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2018-2019 Fetch.AI Limited
+#   Copyright 2018-2022 Fetch.AI Limited
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -39,6 +39,7 @@ from aea.cli.generate_key import generate_key
 from aea.cli.generate_wealth import generate_wealth
 from aea.cli.get_address import get_address
 from aea.cli.get_multiaddress import get_multiaddress
+from aea.cli.get_public_key import get_public_key
 from aea.cli.get_wealth import get_wealth
 from aea.cli.init import init
 from aea.cli.install import install
@@ -62,6 +63,7 @@ from aea.cli.search import search
 from aea.cli.transfer import transfer
 from aea.cli.upgrade import upgrade
 from aea.cli.utils.click_utils import registry_path_option
+from aea.cli.utils.config import get_registry_path_from_cli_config
 from aea.cli.utils.context import Context
 from aea.cli.utils.loggers import logger, simple_verbosity_option
 from aea.helpers.win32 import enable_ctrl_c_support
@@ -89,8 +91,11 @@ def cli(
 ) -> None:
     """Command-line tool for setting up an Autonomous Economic Agent (AEA)."""
     verbosity_option = click_context.meta.pop("verbosity")
-    click_context.obj = Context(cwd=".", verbosity=verbosity_option)
-    click_context.obj.registry_path = registry_path
+    if not registry_path:
+        registry_path = get_registry_path_from_cli_config()
+    click_context.obj = Context(
+        cwd=".", verbosity=verbosity_option, registry_path=registry_path
+    )
     click_context.obj.set_config("skip_consistency_check", skip_consistency_check)
 
     # enables CTRL+C support on windows!
@@ -112,6 +117,7 @@ cli.add_command(generate_key)
 cli.add_command(generate_wealth)
 cli.add_command(generate)
 cli.add_command(get_address)
+cli.add_command(get_public_key)
 cli.add_command(get_multiaddress)
 cli.add_command(get_wealth)
 cli.add_command(init)
