@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2018-2019 Fetch.AI Limited
+#   Copyright 2018-2022 Fetch.AI Limited
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -23,7 +23,7 @@ import logging
 import platform
 
 
-logger = logging.getLogger(__file__)
+_default_logger = logging.getLogger(__name__)
 
 
 def enable_ctrl_c_support() -> None:  # pragma: no cover
@@ -34,4 +34,4 @@ def enable_ctrl_c_support() -> None:  # pragma: no cover
     kernel32 = ctypes.WinDLL("kernel32", use_last_error=True)  # type: ignore
 
     if not kernel32.SetConsoleCtrlHandler(None, False):
-        logger.debug(f"SetConsoleCtrlHandler Error: {ctypes.get_last_error()}")  # type: ignore
+        _default_logger.debug(f"SetConsoleCtrlHandler Error: {ctypes.get_last_error()}")  # type: ignore
